
var xwl = "xwl"

function EventReport(gameId, platform, sdk, debug) {
    if (typeof EventReport.instance === 'object') {
        return EventReport.instance
    }
    this.game = gameId;
    this.platform = platform;
    this.sdk = sdk;
    this.debug = debug;
    this.kv = {};
    this.passInfo = {};
    // 缓存
    EventReport.instance = this;
}

EventReport.prototype.getReportApi = function () {
    return "/event_report_v2"
}

EventReport.prototype.getStartCustomsPassApi = function () {
    return "/report_v2_start_customs_pass"
}

EventReport.prototype.getPreDomain = function () {
    let predomain = "https://bsqb.lynlzqy.com"
    if (this.debug) {
        predomain = "https://test.lynlzqy.com/bsqb"
    }
    return predomain
}

EventReport.prototype.setKVForClient = function (k,v) {
    let debug =false
    if(!debug){
        localStorage.setItem(k,v)
    }else{
        this.kv[k] = v
    }
}

EventReport.prototype.getKVForClient = function (k) {
    let debug =false
    if(!debug){
        return localStorage.getItem(k)
    }
    if(this.kv.hasOwnProperty(k)){
        return this.kv[k]
    }else{
        return null
    }
}

EventReport.prototype.getUUid = function () {
    let uuid = this.getKVForClient("event_report_uuid")
    let time = this.getKVForClient("event_report_register_time")

    //老用户
    if (uuid != null && uuid != "") {
        return uuid
    }else{
        //新用户
        var e = (new Date).getTime();
        uuid = String(Math.random()).replace(".", "").slice(1, 11) + "-" + e
        this.setKVForClient("event_report_uuid", uuid)
    }

    if (time == null || time == "") {
        this.setKVForClient("event_report_register_time",this.getTimeStamp())
    }
    return uuid
}

EventReport.prototype.getTimeStamp= function () {
    var time = Date.parse( new Date() ).toString();//获取到毫秒的时间戳，精确到毫秒
    time = time.substr(0,10);//精确到秒
    return time
}

EventReport.prototype.logReqData = function (url, reqData,resData) {
    console.log(this.debug)
    if (this.debug) {
        console.log(url, reqData,resData);
    }
}

EventReport.prototype.ajax = function (url, data, successFn,errFn) {

    var xhr = new XMLHttpRequest();
    xhr.open("POST", url, true);
    // 添加http头，发送信息至服务器时内容编码类型
    xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
    xhr.onreadystatechange =  () => {
        if (xhr.readyState == 4 && (xhr.status == 200 || xhr.status == 304)) {
            try {
                let resTxt = JSON.parse(xhr.responseText)
                this.logReqData(url,data,resTxt)
                successFn.call(this, resTxt);
            }catch (e) {
                console.log(e)
                errFn.call(this, "err");
            }
        } else if (xhr.readyState == 4 && (xhr.status != 200 || xhr.status != 304)) {
            errFn.call(this, "err");
        }
    };
    xhr.send(data);
}

EventReport.prototype.isSameDay = function(t1,t2) {
    let d1 = new Date(t1*1000);
    let d2 = new Date(t2*1000);
    if(d1.getFullYear()==d2.getFullYear() && d1.getDay()==d2.getDay() && d1.getMonth()==d2.getMonth() ){
        return true
    }else{
        return false
    }
}

EventReport.prototype.getCurrentTime =  function(fn){

    let uri = this.getPreDomain()+"/GetTime"
    this.ajax(uri, null,  (res) => {
        fn(res.currentDate)
        return
    }, (err) => {
        console.error(err)
        fn(this.getTimeStamp())
        return
    })
}

EventReport.prototype.reportLogin =  function () {
    this.getCurrentTime((currentTime)=>{
        let event_name = "登录"

        let uuid =  this.getUUid()

        // 0 为老用户 1 为新用户
        let parmas = {}
        if(this.isSameDay(this.getKVForClient("event_report_register_time"),currentTime)){
            parmas["If_new"] = 1
        }else{
            parmas["If_new"] = 0
        }

        this.report(uuid,event_name,this.getReportApi(),parmas,(res)=>{
            //console.log(res)
        },(err)=>{
            console.error(err)
        })
    })


}

EventReport.prototype.reportVideoAds =  function (event_name) {

    let uuid =  this.getUUid()

    let parmas = {}

    this.report(uuid,event_name,this.getReportApi(),parmas,(res)=>{
        //console.log(res)
    },(err)=>{
        console.error(err)
    })
}

EventReport.prototype.reportNoviceGuidance =  function (event_name) {

    let uuid =  this.getUUid()

    let parmas = {}

    this.getCurrentTime((currentTime)=>{
        //新手才上报
        if(this.isSameDay(this.getKVForClient("event_report_register_time"),currentTime)){
            this.report(uuid,event_name,this.getReportApi(),parmas,(res)=>{
                //console.log(res)
            },(err)=>{
                console.error(err)
            })
        }
    })
}

EventReport.prototype.reportLoading = function (event_name) {
    let uuid = this.getUUid()
    this.getCurrentTime((currentTime) => {
        // 0 为老用户 1 为新用户
        let parmas = {}
        if (this.isSameDay(this.getKVForClient("event_report_register_time"), currentTime)) {
            parmas["If_new"] = 1
        } else {
            parmas["If_new"] = 0
        }
        if (parmas["If_new"] = 0) {
            return;
        }
        this.report(uuid, "加载" + event_name, this.getReportApi(), parmas, (res) => {
            //console.log(res)
        }, (err) => {
            console.error(err)
        })
    })
}

EventReport.prototype.reportCustomize =  function (event_name) {

    let uuid =  this.getUUid()

    let parmas = {}



    this.report(uuid,event_name,this.getReportApi(),parmas,(res)=>{
        //console.log(res)
    },(err)=>{
        console.error(err)
    })
}

EventReport.prototype.reportStartCustomsPass =  function (event_name) {

    this.getCurrentTime((currentTime)=>{
        let uuid =  this.getUUid()

        // 0 为老用户 1 为新用户
        let parmas = {}
        if(this.isSameDay(this.getKVForClient("event_report_register_time"),currentTime)){
            parmas["If_new"] =1
        }else{
            parmas["If_new"] =0
        }

        var startCustomsPassTime =new Date().getTime();

        this.report(uuid,event_name,this.getStartCustomsPassApi(),parmas,(res)=>{
            if(res.code == 0){
                this.passInfo[event_name] = {
                    time: startCustomsPassTime,
                    sessionid:res.sessionId
                }
                this.currentCustomsPassName = event_name
            }
        },(err)=>{
            console.error(err)
        })
    })


}

EventReport.prototype.reportSuccCustomsPass =  function () {
    this.endCustomsPass(this.currentCustomsPassName,1)
}

EventReport.prototype.reportFailCustomsPass =  function () {
    this.endCustomsPass(this.currentCustomsPassName,0)
}

EventReport.prototype.endCustomsPass =  function (event_name,isPass) {

    let uuid =  this.getUUid()

    let endCustomsPassTime =new Date().getTime();

    let customsPassInfo = this.passInfo[event_name]

    let sessionID = customsPassInfo["sessionid"]
    let time = customsPassInfo["time"]
     time = Math.floor((endCustomsPassTime - time)/1000)
    let parmas = {
        ispassed:isPass,
        time:time,
        session_id:sessionID
    }

    this.getCurrentTime((currentTime)=>{
        if(this.isSameDay(this.getKVForClient("event_report_register_time"),currentTime)){
            parmas["If_new"] =1
        }else{
            parmas["If_new"] =0
        }

        this.report(uuid,event_name,this.getReportApi(),parmas,(res)=>{
            //console.log(res)
        },(err)=>{
            console.error(err)
        })
    })


}

EventReport.prototype.report = function(user_id, event_name,api, parmas,successFn,errFn) {

    let req = {
        user_id: user_id,
        event_name: event_name,
    };

    if (parmas != "" || Object.keys(parmas).length != 0) {
        req["parmas"] = JSON.stringify(parmas);
    }

    let data = "";
    for (let k in req) {
        data = data + k + "=" + req[k] + "&";
    }
    let url = this.getPreDomain() + api + "/" + this.game + "/" + this.sdk + "/" + this.platform

    this.ajax(url, data,  (res) => {
        successFn(res)
    }, (err) => {
        console.log("异常",err)
        errFn(err)
    })
}
 window["EventReport"] = EventReport;

